@@ -24,7 +24,7 @@ fix() {
 }
 
 # @cmd Code for setup shell to load argc completion script
-# @option -s --shell[=bash|elvish|fish|nushell|powershell|xonsh|zsh] shell type
+# @option -s --shell[=bash|elvish|fish|nushell|powershell|xonsh|zsh|tcsh] shell type
 # @arg cmds* any other scripts based on argc
 setup-shell() {
     case $argc_shell in
@@ -35,6 +35,7 @@ setup-shell() {
      powershell) echo "argc --argc-completions powershell ${argc_cmds[@]} | Out-String | Invoke-Expression" ;;
      xonsh) echo "exec(\$(argc --argc-completions xonsh ${argc_cmds[@]}))" ;;
      zsh) echo "source <(argc --argc-completions zsh ${argc_cmds[@]})" ;;
+     tcsh) echo "eval \`argc --argc-completions tcsh ${argc_cmds[@]}\`" ;;
     esac
 }
 
