@@ -1,5 +1,5 @@
 use crate::param::{
-    ChoiceData, DefaultData, FlagOptionParam, Modifier, ParamData, PositionalParam,
+    ChoiceValue, DefaultValue, EnvParam, FlagOptionParam, Modifier, ParamData, PositionalParam,
 };
 use crate::utils::{is_choice_value_terminate, is_default_value_terminate};
 use crate::Result;
@@ -38,6 +38,8 @@ pub(crate) enum EventData {
     Cmd(String),
     /// Define alias for a subcommand, e.g. `@alias t,tst`
     Aliases(Vec<String>),
+    /// Define a env param
+    Env(EnvParam),
     /// Define a flag or option parameter
     FlagOption(FlagOptionParam),
     /// Define a positional parameter
@@ -82,6 +84,11 @@ pub(crate) fn parse(source: &str) -> Result<Vec<Event>> {
                                 line_idx += take_comment_lines(&lines, line_idx + 1, &mut text);
                                 EventData::Cmd(text)
                             }
+                            EventData::Env(mut param) => {
+                                line_idx +=
+                                    take_comment_lines(&lines, line_idx + 1, &mut param.describe);
+                                EventData::Env(param)
+                            }
                             EventData::FlagOption(mut param) => {
                                 line_idx +=
                                     take_comment_lines(&lines, line_idx + 1, &mut param.describe);
@@ -126,15 +133,12 @@ fn parse_fn(input: &str) -> nom::IResult<&str, Option<EventData>> {
 
 // Parse fn likes `function foo`
 fn parse_fn_keyword(input: &str) -> nom::IResult<&str, &str> {
-    preceded(tuple((space0, tag("function"), space1)), parse_fn_name)(input)
+    preceded(terminated(tag("function"), space1), parse_fn_name)(input)
 }
 
 // Parse fn likes `foo ()`
 fn parse_fn_no_keyword(input: &str) -> nom::IResult<&str, &str> {
-    preceded(
-        space0,
-        terminated(parse_fn_name, tuple((space0, char('('), space0, char(')')))),
-    )(input)
+    terminated(parse_fn_name, tuple((space0, char('('), space0, char(')'))))(input)
 }
 
 fn parse_tag(input: &str) -> nom::IResult<&str, Option<EventData>> {
@@ -179,7 +183,7 @@ fn parse_tag_meta(input: &str) -> nom::IResult<&str, Option<EventData>> {
 }
 
 fn parse_tag_param(input: &str) -> nom::IResult<&str, Option<EventData>> {
-    let check = peek(alt((tag("option"), tag("flag"), tag("arg"))));
+    let check = peek(alt((tag("option"), tag("flag"), tag("env"), tag("arg"))));
     let arg = alt((
         map(
             preceded(pair(tag("flag"), space1), parse_flag_param),
@@ -189,6 +193,10 @@ fn parse_tag_param(input: &str) -> nom::IResult<&str, Option<EventData>> {
             preceded(pair(tag("option"), space1), parse_option_param),
             |param| Some(EventData::FlagOption(param)),
         ),
+        map(
+            preceded(pair(tag("env"), space1), parse_env_param),
+            |param| Some(EventData::Env(param)),
+        ),
         map(
             preceded(pair(tag("arg"), space1), parse_positional_param),
             |param| Some(EventData::Positional(param)),
@@ -265,6 +273,24 @@ fn parse_no_long_option_param(input: &str) -> nom::IResult<&str, FlagOptionParam
     )(input)
 }
 
+// Parse `@env`
+fn parse_env_param(input: &str) -> nom::IResult<&str, EnvParam> {
+    map(
+        pair(
+            alt((
+                parse_param_modifer_choices_default,
+                parse_param_modifer_choices_fn,
+                parse_param_modifer_choices,
+                parse_param_assign_fn,
+                parse_param_assign,
+                parse_param_modifer,
+            )),
+            parse_tail,
+        ),
+        |(arg, describe)| EnvParam::new(arg, describe),
+    )(input)
+}
+
 // Parse `@option`, positional only
 fn parse_positional_param(input: &str) -> nom::IResult<&str, PositionalParam> {
     map(
@@ -313,7 +339,6 @@ fn parse_no_long_flag_param(input: &str) -> nom::IResult<&str, FlagOptionParam>
     )(input)
 }
 
-// Parse `str*` `str`
 fn parse_with_long_flag_name(input: &str) -> nom::IResult<&str, ParamData> {
     alt((
         map(terminated(parse_param_name, tag("*")), |mut arg| {
@@ -324,7 +349,6 @@ fn parse_with_long_flag_name(input: &str) -> nom::IResult<&str, ParamData> {
     ))(input)
 }
 
-// Parse 'ch*' or 'ch`
 fn parse_no_long_flag_name(input: &str) -> nom::IResult<&str, ParamData> {
     fn parser(input: &str) -> nom::IResult<&str, ParamData> {
         map(satisfy(is_short_char), |ch| {
@@ -370,7 +394,7 @@ fn parse_param_modifer(input: &str) -> nom::IResult<&str, ParamData> {
             pair(parse_param_name, preceded(tag("*"), opt(parse_multi_char))),
             |(mut arg, multi_char)| {
                 match multi_char {
-                    Some(c) => arg.modifer = Modifier::MultiCharOptional(c),
+                    Some(c) => arg.modifer = Modifier::DelimiterOptional(c),
                     None => {
                         if let Some(name) = arg.name.strip_suffix('-') {
                             arg.name = name.to_string();
@@ -387,7 +411,7 @@ fn parse_param_modifer(input: &str) -> nom::IResult<&str, ParamData> {
             pair(parse_param_name, preceded(tag("+"), opt(parse_multi_char))),
             |(mut arg, multi_char)| {
                 let modifier = match multi_char {
-                    Some(c) => Modifier::MultiCharRequired(c),
+                    Some(c) => Modifier::DelimiterRequired(c),
                     None => Modifier::MultipleRequired,
                 };
                 arg.modifer = modifier;
@@ -409,7 +433,7 @@ fn parse_param_assign(input: &str) -> nom::IResult<&str, ParamData> {
     map(
         separated_pair(parse_param_name, char('='), parse_default_value),
         |(mut arg, value)| {
-            arg.default = Some(DefaultData::Value(value.to_string()));
+            arg.default = Some(DefaultValue::Value(value.to_string()));
             arg
         },
     )(input)
@@ -420,7 +444,7 @@ fn parse_param_assign_fn(input: &str) -> nom::IResult<&str, ParamData> {
     map(
         separated_pair(parse_param_name, char('='), parse_value_fn),
         |(mut arg, f)| {
-            arg.default = Some(DefaultData::Fn(f.to_string()));
+            arg.default = Some(DefaultValue::Fn(f.to_string()));
             arg
         },
     )(input)
@@ -433,11 +457,11 @@ fn parse_param_modifer_choices_default(input: &str) -> nom::IResult<&str, ParamD
             delimited(char('['), parse_choices_default, char(']')),
         ),
         |(mut arg, (values, default))| {
-            arg.choice = Some(ChoiceData::Values(
+            arg.choice = Some(ChoiceValue::Values(
                 values.iter().map(|v| v.to_string()).collect(),
             ));
             if let Some(value) = default {
-                arg.default = Some(DefaultData::Value(value.to_string()));
+                arg.default = Some(DefaultValue::Value(value.to_string()));
             }
             arg
         },
@@ -451,7 +475,7 @@ fn parse_param_modifer_choices(input: &str) -> nom::IResult<&str, ParamData> {
             delimited(char('['), parse_choices, char(']')),
         ),
         |(mut arg, values)| {
-            arg.choice = Some(ChoiceData::Values(
+            arg.choice = Some(ChoiceValue::Values(
                 values.iter().map(|v| v.to_string()).collect(),
             ));
             arg
@@ -466,13 +490,12 @@ fn parse_param_modifer_choices_fn(input: &str) -> nom::IResult<&str, ParamData>
             delimited(char('['), pair(opt(char('?')), parse_value_fn), char(']')),
         ),
         |(mut arg, (validate, f))| {
-            arg.choice = Some(ChoiceData::Fn(f.into(), validate.is_none()));
+            arg.choice = Some(ChoiceValue::Fn(f.into(), validate.is_none()));
             arg
         },
     )(input)
 }
 
-// Parse `str`
 fn parse_param_name(input: &str) -> nom::IResult<&str, ParamData> {
     map(parse_name, ParamData::new)(input)
 }
@@ -722,6 +745,8 @@ fn take_comment_lines(lines: &[&str], idx: usize, output: &mut String) -> usize
 mod tests {
     use super::*;
 
+    use crate::param::Param;
+
     macro_rules! assert_token {
         ($comment:literal, Ignore) => {
             assert_eq!(parse_line($comment).unwrap().1, None)
@@ -1008,7 +1033,7 @@ mod tests {
         assert_token!("foo ()", Func, "foo");
         assert_token!("foo  ()", Func, "foo");
         assert_token!("foo ( )", Func, "foo");
-        assert_token!(" foo ()", Func, "foo");
+        assert_token!(" foo ()", Ignore);
         assert_token!("foo_bar ()", Func, "foo_bar");
         assert_token!("foo-bar ()", Func, "foo-bar");
         assert_token!("foo:bar ()", Func, "foo:bar");
@@ -1016,13 +1041,12 @@ mod tests {
         assert_token!("foo@bar ()", Func, "foo@bar");
         assert_token!("function foo", Func, "foo");
         assert_token!("function  foo", Func, "foo");
-        assert_token!(" function foo", Func, "foo");
+        assert_token!(" function foo", Ignore);
         assert_token!("function foo_bar", Func, "foo_bar");
         assert_token!("function foo-bar", Func, "foo-bar");
         assert_token!("function foo:bar", Func, "foo:bar");
         assert_token!("function foo.bar", Func, "foo.bar");
         assert_token!("function foo@bar", Func, "foo@bar");
-        assert_token!("foo=bar", Ignore);
         assert_token!("#!/bin/bash", Ignore);
     }
 
