@@ -7,9 +7,21 @@ use std::{
 };
 use which::which;
 
-pub const INTERNAL_MODE: &str = "___internal___";
+pub const INTERNAL_SYMBOL: &str = "___internal___";
+pub const VARIABLE_PREFIX: &str = "argc_";
+pub const BEFORE_HOOK: &str = "_argc_before";
+pub const AFTER_HOOK: &str = "_argc_after";
+pub const ROOT_NAME: &str = "prog";
+
+pub(crate) const META_DOTENV: &str = "dotenv";
+pub(crate) const META_DEFAULT_SUBCOMMAND: &str = "default-subcommand";
+pub(crate) const META_INHERIT_FLAG_OPTIONS: &str = "inherit-flag-options";
+pub(crate) const META_NO_INHERIT_ENV: &str = "no-inherit-env";
+pub(crate) const META_SYMBOL: &str = "symbol";
+pub(crate) const META_COMBINE_SHORTS: &str = "combine-shorts";
+
+pub(crate) const MAX_ARGS: usize = 999999;
 
-/// Transform into upper case string with an underscore between words. `foo-bar` => `FOO-BAR`
 pub fn to_cobol_case(value: &str) -> String {
     Converter::new()
         .set_pattern(Pattern::Uppercase)
@@ -111,7 +123,7 @@ pub fn run_param_fns(
                 process::Command::new(shell)
                     .args(shell_extra_args)
                     .arg(&script_file)
-                    .arg(INTERNAL_MODE)
+                    .arg(INTERNAL_SYMBOL)
                     .arg(&param_fn)
                     .args(args)
                     .envs(envs)
@@ -171,6 +183,19 @@ pub fn path_env_with_exe() -> String {
     path_env
 }
 
+pub fn expand_dotenv(value: &str) -> String {
+    let value = if value.is_empty() { ".env" } else { value };
+    format!("[ -f {value} ] && set -o allexport && . {value} && set +o allexport")
+}
+
+pub fn sanitize_var_name(id: &str) -> String {
+    id.replace(['-', '.', ':'], "_")
+}
+
+pub fn argc_var_name(id: &str) -> String {
+    format!("{VARIABLE_PREFIX}{}", sanitize_var_name(id))
+}
+
 #[cfg(test)]
 mod tests {
     use super::*;
